==> coin3_3.0.0.orig.tar.gz: Coin-3.0.0/src/draggers/all-draggers-cpp.cpp <==
/**************************************************************************\
 *
 *  This file is part of the Coin 3D visualization library.
 *  Copyright (C) 1998-2008 by Kongsberg SIM.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  ("GPL") version 2 as published by the Free Software Foundation.
 *  See the file LICENSE.GPL at the root directory of this source
 *  distribution for additional information about the GNU GPL.
 *
 *  For using Coin with software that can not be combined with the GNU
 *  GPL, and for taking advantage of the additional benefits of our
 *  support services, please contact Kongsberg SIM about acquiring
 *  a Coin Professional Edition License.
 *
 *  See http://www.coin3d.org/ for more information.
 *
 *  Kongsberg SIM, Postboks 1283, Pirsenteret, 7462 Trondheim, NORWAY.
 *  http://www.sim.no/  sales@sim.no  coin-support@coin3d.org
 *
\**************************************************************************/

#include "SoDragger.cpp"
#include "SoCenterballDragger.cpp"
#include "SoDirectionalLightDragger.cpp"
#include "SoDragPointDragger.cpp"
#include "SoHandleBoxDragger.cpp"
#include "SoJackDragger.cpp"
#include "SoPointLightDragger.cpp"
#include "SoRotateCylindricalDragger.cpp"
#include "SoRotateDiscDragger.cpp"
#include "SoRotateSphericalDragger.cpp"
#include "SoScale1Dragger.cpp"
#include "SoScale2Dragger.cpp"
#include "SoScale2UniformDragger.cpp"
#include "SoScaleUniformDragger.cpp"
#include "SoSpotLightDragger.cpp"
#include "SoTabBoxDragger.cpp"
#include "SoTabPlaneDragger.cpp"
#include "SoTrackballDragger.cpp"
#include "SoTransformBoxDragger.cpp"
#include "SoTransformerDragger.cpp"
#include "SoTranslate1Dragger.cpp"
#include "SoTranslate2Dragger.cpp"

==> coin3_3.1.2.orig.tar.gz: Coin-3.1.2/src/draggers/all-draggers-cpp.cpp <==
/**************************************************************************\
 *
 *  This file is part of the Coin 3D visualization library.
 *  Copyright (C) 1998-2009 by Kongsberg SIM.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  ("GPL") version 2 as published by the Free Software Foundation.
 *  See the file LICENSE.GPL at the root directory of this source
 *  distribution for additional information about the GNU GPL.
 *
 *  For using Coin with software that can not be combined with the GNU
 *  GPL, and for taking advantage of the additional benefits of our
 *  support services, please contact Kongsberg SIM about acquiring
 *  a Coin Professional Edition License.
 *
 *  See http://www.coin3d.org/ for more information.
 *
 *  Kongsberg SIM, Postboks 1283, Pirsenteret, 7462 Trondheim, NORWAY.
 *  http://www.sim.no/  sales@sim.no  coin-support@coin3d.org
 *
\**************************************************************************/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif // HAVE_CONFIG_H

#ifdef HAVE_DRAGGERS

#include "SoDragger.cpp"
#include "SoCenterballDragger.cpp"
#include "SoDirectionalLightDragger.cpp"
#include "SoDragPointDragger.cpp"
#include "SoHandleBoxDragger.cpp"
#include "SoJackDragger.cpp"
#include "SoPointLightDragger.cpp"
#include "SoRotateCylindricalDragger.cpp"
#include "SoRotateDiscDragger.cpp"
#include "SoRotateSphericalDragger.cpp"
#include "SoScale1Dragger.cpp"
#include "SoScale2Dragger.cpp"
#include "SoScale2UniformDragger.cpp"
#include "SoScaleUniformDragger.cpp"
#include "SoSpotLightDragger.cpp"
#include "SoTabBoxDragger.cpp"
#include "SoTabPlaneDragger.cpp"
#include "SoTrackballDragger.cpp"
#include "SoTransformBoxDragger.cpp"
#include "SoTransformerDragger.cpp"
#include "SoTranslate1Dragger.cpp"
#include "SoTranslate2Dragger.cpp"

#endif // HAVE_DRAGGERS
